============
Installation
============

At the command line::

    $ pip install networking-fujitsu

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv networking-fujitsu
    $ pip install networking-fujitsu